// https://www.radix-ui.com/primitives/docs/components/tooltip

import React, { ReactNode } from 'react';
import * as TooltipPrimitive from '@radix-ui/react-tooltip';

export interface BarTooltipProps {
  x: number;
  y: number;
  content: React.ReactNode;
}

export const BarplotTooltip: React.FC<BarTooltipProps> = ({ x, y, content }) => {
  return (
    <div className="absolute font-sans bg-light border border-secondary text-secondary p-2" style={{ left: `${x}px`, top: `${y}px` }}>
      {content}
    </div>
  );
};

const TooltipProvider = TooltipPrimitive.Provider;
const TooltipTrigger = TooltipPrimitive.Trigger;

export type TooltipProps = {
  children: ReactNode;
  disabled?: boolean;
};

const Tooltip: React.FC<TooltipProps> = ({ disabled, children }) => {
  if (disabled) {
    return null;
  }

  return <TooltipPrimitive.Root>{children}</TooltipPrimitive.Root>;
};

const TooltipContent = React.forwardRef<
  React.ElementRef<typeof TooltipPrimitive.Content>,
  React.ComponentPropsWithoutRef<typeof TooltipPrimitive.Content> & TooltipProps
>(({ className, sideOffset = 4, disabled = false, ...props }, ref) => {
  if (disabled) {
    return null;
  }

  return (
    <TooltipPrimitive.Content
      ref={ref}
      sideOffset={sideOffset}
      className={
        'z-50 overflow-hidden rounded bg-light px-2 py-1 shadow text-xs border border-secondary-200 text-dark animate-in fade-in-0 zoom-in-95 data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=closed]:zoom-out-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2'
      }
      {...props}
    />
  );
});
TooltipContent.displayName = TooltipPrimitive.Content.displayName;

export { Tooltip, TooltipTrigger, TooltipContent, TooltipProvider };

// Old Tooltip

export type TooltipProps2 = {
  position?: 'top' | 'bottom' | 'left' | 'right';
  children: ReactNode;
  tooltip: string;
  disabled?: boolean;
};
export default function Tooltip2({ position = 'bottom', children, tooltip, disabled = false }: TooltipProps2) {
  return (
    <div className="group relative cursor-pointer">
      <div className="">{children}</div>
      {!disabled && (
        <div className="z-50">
          <span
            className={`absolute hidden group-hover:inline-block bg-neutral-900 text-white text-xs p-2 whitespace-nowrap rounded ${
              position === 'top' ? 'left-1/2 -translate-x-1/2 bottom-[calc(100%+5px)]' : ''
            } ${position === 'bottom' ? 'left-1/2 -translate-x-1/2 top-[calc(100%+5px)]' : ''} ${
              position === 'left' ? 'top-1/2 -translate-y-1/2 right-[calc(100%+5px)]' : ''
            } ${position === 'right' ? 'top-1/2 -translate-y-1/2 left-[calc(100%+5px)]' : ''} `}
          >
            {tooltip}
          </span>
          <span
            className={`absolute hidden group-hover:inline-block border-[6px] ${
              position === 'top'
                ? 'left-1/2 -translate-x-1/2 bottom-full border-l-transparent border-r-transparent border-b-0 border-t-neutral-900'
                : ''
            } ${
              position === 'bottom'
                ? 'left-1/2 -translate-x-1/2 top-full border-l-transparent border-r-transparent border-t-0 border-b-neutral-900'
                : ''
            } ${
              position === 'left'
                ? 'top-1/2 -translate-y-1/2 right-full border-t-transparent border-b-transparent border-r-0 border-l-neutral-900'
                : ''
            } ${
              position === 'right'
                ? 'top-1/2 -translate-y-1/2 left-full border-t-transparent border-b-transparent border-l-0 border-r-neutral-900'
                : ''
            } `}
          ></span>
        </div>
      )}
    </div>
  );
}
