import React, { useState, useEffect } from 'react';
import Input from '@graphpolaris/shared/lib/components/inputs';
import { useGraphQueryResultMeta } from '@graphpolaris/shared/lib/data-access';
import { DimensionType } from '@graphpolaris/shared/lib/schema';
import { CompressedElement } from '@graphpolaris/shared/lib/data-access/statistics';

type Props = {
  value: string | undefined;
  onChange: (val: string | number) => void;
  element: 'node' | 'edge';
  dimension?: DimensionType[];
  disabled?: boolean;
};

const extractAttributesByDimension = (summaryGraph: CompressedElement, dimensions: DimensionType[]): string[] => {
  const selectedAttributes: { [label: string]: string[] } = {};

  Object.keys(summaryGraph.types).map((label) => {
    selectedAttributes[label] = [];
    Object.keys(summaryGraph.types[label].attributes).map((attribute) => {
      const dim: DimensionType = summaryGraph.types[label]?.attributes[attribute].dimension as DimensionType;
      dimensions.includes(dim) && selectedAttributes[label].push(attribute);
    });
  });

  let commonAttributes: Set<string> = new Set();
  Object.values(selectedAttributes).forEach((attributes) => {
    if (commonAttributes.size === 0) {
      commonAttributes = new Set(attributes);
    } else {
      commonAttributes = new Set([...commonAttributes].filter((attr) => attributes.includes(attr)));
    }
  });

  return commonAttributes ? Array.from(commonAttributes) : [];
};

export default function Accessor({ value, onChange, element, dimension, disabled = false }: Props) {
  const resultStatistics = useGraphQueryResultMeta();
  const [options, setOptions] = useState<string[]>([]);
  const [loading, setLoading] = useState<boolean>(true);

  useEffect(() => {
    setLoading(Object.keys(resultStatistics.nodes.types).length === 0 && Object.keys(resultStatistics.edges.types).length === 0);
  }, [resultStatistics]);

  useEffect(() => {
    if (!loading) {
      setOptions(extractAttributesByDimension(resultStatistics[element === 'node' ? 'nodes' : 'edges'], dimension || ['categorical']));
      disabled = true;
    } else {
      disabled = false;
    }
  }, [resultStatistics, loading, element, dimension]);

  return (
    <div className="mb-2">
      <Input type="dropdown" value={value} onChange={(val: string | number) => onChange(val)} options={options} disabled={disabled} />
    </div>
  );
}
