import React, { useState } from 'react';
import Accessor from './accessor';
import Info from '@graphpolaris/shared/lib/components/info';
import Selector from './selector';
import { PanelProps } from '../panel/panel.types';

export default function EncodingPanel({ state, update }: PanelProps) {
  const [encodingUpdates, setEncodingUpdates] = useState<{
    [id: string]: {
      marking: any;
      accessorPath: string;
    };
  }>({});

  const updateEncoding = (encoding: string, val: any, type: 'accessorPath' | 'marking') => {
    setEncodingUpdates((prevState) => {
      if (prevState) {
        return {
          ...prevState,
          [encoding]: {
            ...(prevState[encoding] || {}),
            [type]: val,
          },
        };
      } else {
        return prevState;
      }
    });
  };

  return (
    state && (
      <div>
        {Object.keys(state).map((key) => {
          const item = state[key];
          const value = encodingUpdates[key] ? encodingUpdates[key] : { marking: undefined, accessorPath: undefined };

          return (
            <div key={key} className="bg-secondary-50 p-2 m-1">
              <div className="flex items-center justify-between">
                <h1 className="text-xs">{item.label ? item.label : key}</h1>
                {item.description && <Info tooltip={item.description} />}
              </div>
              <Accessor
                value={value.accessorPath}
                onChange={(value: string | number) => updateEncoding(key, value, 'accessorPath')}
                // onChange={(value: string | number) => update(key, { ...state[key], accessorPath: value })}
                element={item.element}
                dimension={item.dimension ?? []}
              />
              {value.accessorPath && (
                <Selector
                  key={key}
                  selectorType={item.selector}
                  elementType={item.element}
                  marking={value.marking}
                  onChange={(value: any) => updateEncoding(key, value, 'marking')}
                  accessorPath={value.accessorPath}
                />
              )}
            </div>
          );
        })}
      </div>
    )
  );
}
