import React from 'react';
import { FormTitle } from '@graphpolaris/shared/lib/components/forms';
import { AutoAwesome, CandlestickChart, LockOpen, Settings } from '@mui/icons-material';
import { useVisualization } from '@graphpolaris/shared/lib/data-access';
import PanelItem from './panel-item';

type Props = {
  onClose: any;
  activeTab: number;
  setActiveTab: any;
};

export default function PanelHeader({ onClose, activeTab, setActiveTab }: Props) {
  const vis = useVisualization();

  let encodingsExist: boolean = !!vis.settings[vis.activeVisualization || '']?.encodings || false;
  let settingsExist: boolean = !!vis.settings[vis.activeVisualization || '']?.settings || false;
  let interactionsExist: boolean = !!vis.settings[vis.activeVisualization || '']?.interactions || false;

  return (
    <div className="flex flex-col pt-2 bg-secondary-100">
      <FormTitle title="Settings" onClose={onClose} />
      <ul className="flex flex-wrap pt-4 pl-5 text-sm font-medium text-center text-gray-500 dark:text-gray-400">
        {encodingsExist && (
          <PanelItem active={activeTab === 0} onClick={() => setActiveTab(0)} icon={<AutoAwesome />} tooltip="Encodings" />
        )}
        {settingsExist && <PanelItem active={activeTab === 1} onClick={() => setActiveTab(1)} icon={<Settings />} tooltip="Settings" />}
        {interactionsExist && (
          <PanelItem active={activeTab === 2} onClick={() => setActiveTab(2)} icon={<CandlestickChart />} tooltip="Interactions" />
        )}
        {(settingsExist || encodingsExist || interactionsExist) && (
          <PanelItem active={activeTab === 3} onClick={() => setActiveTab(3)} icon={<LockOpen />} tooltip="Advanced" />
        )}
      </ul>
    </div>
  );
}
