import React, { useState, useEffect } from 'react';
import { FormActions, FormBody, FormCard, FormDiv, FormHBar } from '@graphpolaris/shared/lib/components/forms';
import { DialogProps } from '@graphpolaris/shared/lib/components/Dialog';
import PanelHeader from './panel-header';
import { SettingsPanel } from '../settings';
import { AdvancedPanel } from '../advanced';
import { EncodingPanel } from '../encodings';
import { InteractionPanel } from '../interactions';
import { useAppDispatch, useVisualization } from '@graphpolaris/shared/lib/data-access';
import { updateConfiguration } from '@graphpolaris/shared/lib/data-access/store/visualizationSlice';
import { ConfigTypes, Configuration } from './panel.types';

export default function VisualizationDialog(props: DialogProps) {
  const dispatch = useAppDispatch();
  const vis = useVisualization();
  const [activeTab, setActiveTab] = useState<number>(1);
  const [configuration, setConfiguration] = useState<Configuration>({});

  useEffect(() => {
    if (vis.activeVisualization) {
      setConfiguration({
        general: vis.settings.general ?? {},
        settings: vis.settings[vis.activeVisualization]?.settings ?? {},
        encodings: vis.settings[vis.activeVisualization]?.encodings ?? {},
        interactions: vis.settings[vis.activeVisualization]?.interactions ?? {},
      });
    }
  }, [vis]);

  const handlePanelUpdate = (configType: ConfigTypes, key: string, value: any) => {
    if (configType === 'configuration') {
      setConfiguration(value);
    } else {
      setConfiguration((prevState) => ({
        ...prevState,
        [configType]: {
          [key]: value,
          ...prevState[configType],
        },
      }));
    }
  };

  const handleSubmit = (e: React.FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    dispatch(updateConfiguration(configuration));
    props.onClose();
  };

  return (
    <>
      {props.open && (
        <FormDiv>
          <FormCard>
            <FormBody onSubmit={handleSubmit}>
              <PanelHeader onClose={props.onClose} activeTab={activeTab} setActiveTab={setActiveTab} />
              {activeTab === 0 && (
                <EncodingPanel state={configuration.encodings} update={(key, value) => handlePanelUpdate('encodings', key, value)} />
              )}
              {activeTab === 1 && (
                <SettingsPanel
                  state={{ general: configuration.general, settings: configuration.settings }}
                  update={(configType, key, value) => handlePanelUpdate(configType, key, value)}
                />
              )}
              {activeTab === 2 && (
                <InteractionPanel
                  state={configuration.interactions}
                  update={(key, value) => handlePanelUpdate('interactions', key, value)}
                />
              )}
              {activeTab === 3 && <AdvancedPanel state={configuration} update={(value) => handlePanelUpdate('configuration', '', value)} />}

              <FormHBar />
              <FormActions onClose={props.onClose} />
            </FormBody>
          </FormCard>
        </FormDiv>
      )}
    </>
  );
}
