import React from 'react';
import { Meta } from '@storybook/react';
import { VisualizationPanel } from '../../visualizationPanel';
import {
  assignNewGraphQueryResult,
  graphQueryResultSlice,
  querybuilderSlice,
  resetGraphQueryResults,
  schemaSlice,
  store,
  visualizationSlice,
} from '../../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import { mockLargeQueryResults } from '../../../mock-data/query-result';
import { setActiveVisualization } from '@graphpolaris/shared/lib/data-access/store/visualizationSlice';

const Component: Meta<typeof VisualizationPanel> = {
  title: 'Visualizations/RawJSONVIS',
  component: VisualizationPanel,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

export const SimpleData = {
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(
      assignNewGraphQueryResult({
        queryID: '1',
        result: {
          type: 'nodelink',
          payload: {
            nodes: [
              { id: 'agent/007', attributes: { name: 'Daniel Craig' } },
              { id: 'villain', attributes: { name: 'Le Chiffre' } },
            ],
            edges: [],
          },
        },
      }),
    );
    dispatch(setActiveVisualization('RawJSONVis'));
  },
};

export const LargeData = {
  args: {
    loading: false,
  },
  play: async () => {
    const dispatch = Mockstore.dispatch;
    dispatch(
      assignNewGraphQueryResult({
        queryID: '1',
        result: {
          type: 'nodelink',
          payload: mockLargeQueryResults,
        },
      }),
    );
    dispatch(setActiveVisualization('RawJSONVis'));
  },
};

export const Empty = {
  play: async () => {
    const dispatch = store.dispatch;
    dispatch(resetGraphQueryResults());
    dispatch(setActiveVisualization('RawJSONVis'));
  },
};

export default Component;
